@@ -8,8 +8,6 @@ import os
 import logging
 import unittest
 from datetime import datetime
-from termcolor import colored
-
 
 class TestResult(unittest.TextTestResult):
 
@@ -30,7 +28,7 @@ class TestResult(unittest.TextTestResult):
         error = "[ERROR]"
 
         if self.showAll:
-            self.stream.writeln(colored(error, 'red'))
+            self.stream.writeln(error)
         elif self.dots:
             self.stream.write('E')
             self.stream.flush()
@@ -43,7 +41,7 @@ class TestResult(unittest.TextTestResult):
         fail = "[FAIL]"
 
         if self.showAll:
-            self.stream.writeln(colored(fail, 'red'))
+            self.stream.writeln(fail)
         elif self.dots:
             self.stream.write('F')
             self.stream.flush()
@@ -64,7 +62,7 @@ class TestResult(unittest.TextTestResult):
         skipped = "[SKIPPED] (%s)" % reason
 
         if self.showAll:
-            self.stream.writeln(colored(skipped, 'yellow'))
+            self.stream.writeln(skipped)
         elif self.dots:
             self.stream.write("s")
             self.stream.flush()
@@ -76,7 +74,7 @@ class TestResult(unittest.TextTestResult):
         ok = "[OK]"
 
         if self.showAll:
-            self.stream.writeln(colored(ok, 'green'))
+            self.stream.writeln(ok)
         elif self.dots:
             self.stream.write('.')
             self.stream.flush()
@@ -127,7 +125,7 @@ def find_tests(path=None):
     return suites
 
 
-def run_tests(suites):
+def run_tests(suites) -> bool:
     log = logging.getLogger('utest')
     print('-' * 90)
     print('Started: ' + datetime.now().strftime("%d-%m-%Y %H:%M:%S"))
@@ -136,7 +134,7 @@ def run_tests(suites):
     # Setting verbosity=1 will display dots instead.
     result = TestRunner(log, verbosity=2).run(suites)
     log.info(result)
-    sys.exit(not result.wasSuccessful())
+    return result.wasSuccessful()
 
 
 # ------------------------------------------------------------------------------
